@@ -1,12 +1,19 @@
 # -*- coding: utf-8 -*-
 
+"""
+Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
+License: BSD, see LICENSE for details.
+
+For further information visit http://code.indifex.com/django-addons
+"""
+
 import os
 import sys
 
 from django.conf import settings
 from django.conf.urls.defaults import *
 
-VERSION = (0, 6, 0, 'final')
+VERSION = (0, 6, 2, 'final')
 
 def get_version():
     version = '%s.%s' % (VERSION[0], VERSION[1])
@@ -30,8 +37,7 @@ def get_meta(name):
     except Exception, e:
         print e
         pass
-    finally:
-        return getattr(mod, 'Meta', None)
+    return getattr(mod, 'Meta', None)
 
 
 
